#!/bin/sh
#
# clamd		Script to start/stop clamd.
#
# chkconfig:	- 47 53 
# description:	clamd is an antivirus daemon.
#
# processname: clamd
# config: /etc/clamd.conf
# pidfile: /var/run/clamav/clamd.pid

# Source function library
. /etc/init.d/functions

# Get network config
. /etc/sysconfig/network

test -f /etc/clamd.conf || exit 0

RETVAL=0

start() {
	# Start daemon.
	# Check if the service is already running?
	if [ ! -f /var/lock/subsys/clamd ]; then
		echo -n $"Starting Clam AV daemon:"
		daemon /usr/sbin/clamd 
		RETVAL=$?
		echo
		[ $RETVAL -eq 0 ] && touch /var/lock/subsys/clamd		
	else
		echo -n $"Clam AV is already running."
		echo
	fi
	return $RETVAL
}
stop() {
	# Stop daemon.
	echo -n $"Stopping Clam AV daemon:"
	killproc clamd
	RETVAL=$?
	echo
	[ $RETVAL -eq 0 ] && rm -f /var/run/clamav/clamd.pid /var/lock/subsys/clamd
	return $RETVAL
}

# See how we were called.
case "$1" in
  start)
	start
	RETVAL=$?
	;;
  stop)
	stop
	RETVAL=$?
	;;
  restart)
	stop
	start
	RETVAL=$?
	;;
  condrestart)
	test -f /var/lock/subsys/clamd && $0 restart || :
	RETVAL=$?
	;;
  status)
	status clamd
	RETVAL=$?
	;;
  reload)
	killproc clamd -HUP
	RETVAL=$?
	;;
  *)
	echo $"Usage: $0 {start|stop|status|restart|condrestart|reload}"
	exit 1
esac

exit $RETVAL

