#!/bin/sh
#
# freshclam      Start/Stop the freshclam.
#
# chkconfig: - 46 54 
# description: freshclam is an update daemon for Clam AV database.
# processname: freshclam
# config: /etc/sysconfig/freshclam
# pidfile: /var/run/clamav/freshclam.pid
#
# (c) 2003/11/12 Petr@Kristof.CZ under GNU GPL 2.0+
#

# Source function library.
. /etc/init.d/functions

# Source our configuration file for these variables.
if [ -f /etc/sysconfig/freshclam ] ; then
	. /etc/sysconfig/freshclam
fi

RETVAL=0

# Set up some common variables before we launch into what might be
# considered boilerplate by now.
prog=freshclam
path=/usr/bin/freshclam

ALLOPTIONS="--checks=$CHECKS --on-update-execute=$ONSUCCESS --on-
error-execute=$ONERROR $FRESHOPTIONS"

if [ $HTTPPROXY ] ; then
   ALLOPTIONS=$ALLOPTIONS" --http-proxy=$HTTPPROXY --proxy-user=$PROXYUSER"
fi

if [ $LOGFILE ] ; then
   ALLOPTIONS=$ALLOPTIONS" --log=$LOGFILE"
fi


start() {
	echo -n $"Starting $prog: "
	daemon $path -d $ALLOPTIONS
	RETVAL=$?
	echo
	[ $RETVAL -eq 0 ] && touch /var/lock/subsys/$prog
	return $RETVAL
}

stop() {
	echo -n $"Stopping $prog: "
	killproc $path
	RETVAL=$?
	echo
	[ $RETVAL -eq 0 ] && rm -f /var/lock/subsys/$prog
	return $RETVAL
}	

restart() {
  	stop
	start
}	

case "$1" in
  start)
  	start
	;;
  stop)
  	stop
	;;
  restart)
  	restart
	;;
  status)
	status $path
	;;
  condrestart)
  	[ -f /var/lock/subsys/$prog ] && restart || :
	;;
  *)
	echo $"Usage: $0 {start|stop|status|reload|restart|condrestart}"
	exit 1
esac

exit $?
